import yaml

def describeInstances(ec2Client,InstanceIds):
    response = ec2Client.describe_instances(InstanceIds=InstanceIds)
    instanceDescriptions = response['Reservations']
    instances = {}
    for instance in instanceDescriptions:
        instance = instance['Instances'][0]
        instanceId = instance['InstanceId']
        instances[instanceId]=instance
    return instances
    
def instanceIdsToPrivateIps(ec2Client,instanceIds):
    instances = describeInstances(ec2Client,instanceIds)
    result = {}
    for instanceId,instance in instances.items():
        result[instanceId] = []
        for networkInterface in instance['NetworkInterfaces']:
            privateIp = networkInterface['PrivateIpAddress']
            result[instanceId].append(privateIp)
    return result



from _readfile import readfile
from _readSshConfig import readSshConfig
from _writefile import writefile
from _fexecvp import fexecvp
from _fnmatches import fnmatches

__all__ = ['fexecvp','readfile','writefile','defaultify','defaultifyDict','isInt','fnmatches','readSshConfig']

def defaultify(value,default):
    if None == value:
        return default
    else:
        return value

def defaultifyDict(dictionary,key,default):
    if key in dictionary:
        return defaultify(dictionary[key],default)
    else:
        return default

def isInt(s):
    try:
        int(s)
        return True
    except ValueError:
        return False



def getInstanceIds(asgClient,asgName):
    asgDescription = asgClient.describe_auto_scaling_groups(AutoScalingGroupNames=[asgName])
    instances = asgDescription['AutoScalingGroups'][0]['Instances']
    instanceIds = [instance['InstanceId'] for instance in instances]
    return instanceIds
